@@ -28,8 +28,9 @@ try:
 except ImportError:
     sentry_logging, sentry_tornado = None, None
 
-from imbi import (endpoints, errors, keychain, openapi, opensearch,
+from imbi import (cors, endpoints, errors, keychain, openapi,
                   permissions, stats, transcoders, version)
+from imbi.clients import opensearch
 from imbi.endpoints import default
 
 LOGGER = logging.getLogger(__name__)
@@ -73,6 +74,20 @@ class Application(sprockets_postgres.ApplicationMixin, app.Application):
 
         errors.set_canonical_server(self.settings['canonical_server_name'])
 
+        if self.settings.get('cors'):
+            kwargs = {
+                name: self.settings['cors'][name]
+                for name in {'allow_any_origin', 'allow_credentials',
+                             'allow_methods', 'exposed_headers',
+                             'max_age'}
+                if name in self.settings['cors']
+            }
+            self.cors_config = cors.CORSConfig(**kwargs)
+        else:
+            self.cors_config = cors.CORSConfig()
+        for allowed_origin in self.settings.get('cors', {}).get('origins', []):
+            self.cors_config.allowed_origins.add(allowed_origin)
+
     def hash_password(self, password: str) -> str:
         """Generate a HMAC-SHA512 hash of `password`."""
         hashed_bytes = self.keychain.hash(password)
@@ -113,8 +128,7 @@ class Application(sprockets_postgres.ApplicationMixin, app.Application):
 
         """Invoked on startup of the application"""
         self.startup_complete = asyncio.Event()
-
-        if sentry_sdk and self.settings['sentry_backend_dsn']:
+        if sentry_sdk and self.settings.get('sentry_backend_dsn'):
             sentry_sdk.init(
                 debug=self.settings['debug'],
                 dsn=self.settings['sentry_backend_dsn'],
@@ -151,16 +165,14 @@ class Application(sprockets_postgres.ApplicationMixin, app.Application):
 
         await self._postgres_connected.wait()
 
-        self.opensearch = opensearch.OpenSearch(
-            self.settings['opensearch'],
-            self.settings['postgres_url'])
+        self.opensearch = opensearch.OpenSearch(self.settings['opensearch'])
         if not await self.opensearch.initialize():
             self.stop(self.loop)
             return
 
         self.startup_complete.set()
         self._ready_to_serve = True
-        LOGGER.info('Application startup complete, ready to serve requests')
+        LOGGER.info('Application startup complete')
 
     async def on_shutdown(self, *_args, **_kwargs) -> None:
         await self.opensearch.stop()
