@@ -22,7 +22,7 @@ from sprockets.http import mixins
 from sprockets.mixins import mediatype
 from tornado import httputil, web
 
-from imbi import errors, session, user, version
+from imbi import cors, errors, session, user, version
 
 LOGGER = logging.getLogger(__name__)
 
@@ -51,7 +51,8 @@ def require_permission(permission):
     return _require_permission
 
 
-class RequestHandler(postgres.RequestHandlerMixin,
+class RequestHandler(cors.CORSMixin,
+                     postgres.RequestHandlerMixin,
                      mixins.ErrorLogger,
                      problemdetails.ErrorWriter,
                      mediatype.ContentMixin,
@@ -82,16 +83,13 @@ class RequestHandler(postgres.RequestHandlerMixin,
         the current user and cookie is cleared.
 
         """
-        if self.application.settings.get('javascript_url'):
-            self.set_header('Access-Control-Allow-Origin', '*')
-
         if not self.application.ready_to_serve:
             return self.send_error(503, reason='Application not ready')
         self.session = session.Session(self)
         await self.session.initialize()
         self._current_user = await self.get_current_user()
         future = super().prepare()
-        if asyncio.isfuture(future):
+        if asyncio.isfuture(future) or asyncio.iscoroutine(future):
             await future
 
     def on_finish(self) -> None:
@@ -221,6 +219,11 @@ class AuthenticatedRequestHandler(RequestHandler):
 
     async def prepare(self) -> None:
         await super().prepare()
+
+        # Don't require authorization for pre-flight requests
+        if self.cors.is_preflight:
+            return
+
         if not self._current_user:
             if self._respond_with_html:
                 return await self.render(
@@ -229,12 +232,20 @@ class AuthenticatedRequestHandler(RequestHandler):
                         'javascript_url'))
             self.set_status(401)
             await self.finish()
+            raise web.Finish()
 
 
 class ValidatingRequestHandler(AuthenticatedRequestHandler):
     """Validates the request against the OpenAPI spec"""
     async def prepare(self) -> None:
         await super().prepare()
+
+        # Don't validate preflight OPTIONS requests... otherwise,
+        # we need to include the OPTIONS stanza in every OpenAPI
+        # path spec
+        if self.cors.is_preflight:
+            return
+
         try:
             self.application.validate_request(self.request)
         except DeserializeError as err:
@@ -267,7 +278,7 @@ class CRUDRequestHandler(ValidatingRequestHandler):
     ID_KEY: typing.Union[str, list] = 'id'
     IS_COLLECTION = False
     FIELDS = None
-    GET_NAME = None  # Used to create link headers for POST requests
+    ITEM_NAME = None  # Used to create link headers for POST requests
     TTL = 300
 
     DELETE_SQL: typing.Optional[str] = None
@@ -434,7 +445,7 @@ class CollectionRequestHandler(CRUDRequestHandler):
     ID_KEY: typing.Union[str, list] = 'id'
     IS_COLLECTION: True
     FIELDS = None
-    GET_NAME = None  # Used to create link headers for POST requests
+    ITEM_NAME = None  # Used to create link headers for POST requests
     COLLECTION_SQL = """SELECT * FROM pg_tables WHERE schemaname = 'v1';"""
     TTL = 300
 
