@@ -7,14 +7,14 @@ class _RequestHandlerMixin:
 
     ID_KEY = 'id'
     FIELDS = ['id', 'name', 'slug', 'icon_class', 'maintained_by',
-              'gitlab_group_name']
+              'gitlab_group_name', 'sentry_team_slug']
     DEFAULTS = {'icon_class': 'fas fa-users', 'maintained_by': []}
 
     GET_SQL = re.sub(r'\s+', ' ', """\
         SELECT id, "name", created_at, created_by,
                last_modified_at, last_modified_by,
                slug, icon_class, maintained_by,
-               gitlab_group_name
+               gitlab_group_name, sentry_team_slug
           FROM v1.namespaces WHERE id=%(id)s""")
 
 
@@ -25,15 +25,17 @@ class CollectionRequestHandler(_RequestHandlerMixin,
     ITEM_NAME = 'namespace'
 
     COLLECTION_SQL = re.sub(r'\s+', ' ', """ \
-        SELECT id, "name", slug, icon_class, maintained_by, gitlab_group_name
+        SELECT id, "name", slug, icon_class, maintained_by, gitlab_group_name,
+               sentry_team_slug
           FROM v1.namespaces ORDER BY "name" ASC""")
 
     POST_SQL = re.sub(r'\s+', ' ', """\
         INSERT INTO v1.namespaces
                     ("name", created_by, slug, icon_class, "maintained_by",
-                     gitlab_group_name)
+                     gitlab_group_name, sentry_team_slug)
              VALUES (%(name)s, %(username)s, %(slug)s, %(icon_class)s,
-                     %(maintained_by)s, %(gitlab_group_name)s)
+                     %(maintained_by)s, %(gitlab_group_name)s,
+                     %(sentry_team_slug)s)
           RETURNING id""")
 
 
@@ -51,5 +53,6 @@ class RecordRequestHandler(_RequestHandlerMixin, base.AdminCRUDRequestHandler):
                slug = %(slug)s,
                icon_class = %(icon_class)s,
                "maintained_by" = %(maintained_by)s,
-               gitlab_group_name = %(gitlab_group_name)s
+               gitlab_group_name = %(gitlab_group_name)s,
+               sentry_team_slug = %(sentry_team_slug)s
          WHERE id=%(id)s""")
