@@ -3,7 +3,7 @@ from imbi.endpoints import base
 
 class GroupsRequestHandler(base.CRUDRequestHandler):
 
-    ENDPOINT = 'ui-groups'
+    NAME = 'ui-groups'
 
     GET_SQL = 'SELECT name FROM v1.groups ORDER BY name ASC;'
     TTL = 300
